.. pyDeltaRCM documentation master file

Welcome to the PyDeltaRCM documentation
#########################################

*pyDeltaRCM* is a computationally efficient, free and open source, and easy-to-customize numerical delta model based on the original DeltaRCM model design (`Matlab DeltaRCM <https://csdms.colorado.edu/wiki/Model:DeltaRCM>`_ model by Man Liang).
*pyDeltaRCM* delivers improved model stability and capabilities, infrastructure to support exploration with minimal boilerplate code, and establishes an approach to extending model capabilities that ensures reproducible and comparable studies.

.. plot:: guides/cover.py

    The weighted random walk of 20 water parcels in a *pyDeltaRCM* model run with default parameters.


Project information
###################

.. toctree::
   :maxdepth: 1

   meta/installing
   meta/contributing
   meta/license
   meta/conduct

.. _user_documentation:

User documentation
##################

.. toctree::
   :maxdepth: 2

   guides/getting_started
   guides/user_guide
   info/index
   examples/index



Developer documentation
#######################

.. toctree::
   :maxdepth: 3

   guides/developer_guide
   reference/index
